#!/bin/bash

. /etc/konahqss/konahqss.inc

arch=$(getarch)

if [ "$(getconf LONG_BIT)" = "64" ]; then
  if [ -f /etc/konahqss/fastmemcpy ]; then
    if [ -d /etc/konahqss/soundrivers/$(uname -r) ]; then
      if [ ! -f /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko.org ]; then
        cp /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko.org
        if [ ! -z "$(grep avx /proc/cpuinfo)" ]; then
          cp /etc/konahqss/soundrivers/$(uname -r)/snd-pcm-avx.ko /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko
        elif [ ! -z "$(grep sse2 /proc/cpuinfo)" ]; then
          cp /etc/konahqss/soundrivers/$(uname -r)/snd-pcm-sse2.ko /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko
        fi
      fi
    fi
  else
    if [ -f /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko.org ]; then
      mv /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko.org /lib/modules/$(uname -r)/kernel/sound/core/snd-pcm.ko 
    fi
  fi
fi

# set timeslice / runtime / clocksource
if [ -f /etc/konahqss/timeslice ]; then
  cat /etc/konahqss/timeslice  > /proc/sys/kernel/sched_rr_timeslice_ms
fi

if [ -f /etc/konahqss/runtime ]; then
  cat /etc/konahqss/runtime > /proc/sys/kernel/sched_rt_runtime_us
fi

if [ -f /etc/konahqss/clocksource ]; then
  cat /etc/konahqss/clocksource > /sys/devices/system/clocksource/clocksource0/current_clocksource
fi

# set to ram for alsa library
lib="libasound.so.2.0.0"
libs=$(getlibs $lib)
if [ ! -z "$libs" ] && [ -f $libs/$lib ]; then
  echo $libs > /etc/konahqss/libs
fi

# set systemd lib to ram
if [ -f $libs/libsystemd.so.0 ]; then
  lib="$(ls -l $libs/libsystemd.so.0|awk '{print $11}')"
  if [ -f $libs/$lib ]; then
    if [ ! -z "$(grep low /etc/konahqss/tone)" ]; then
      libsetoram $libs/$lib $lib
    fi
  fi
fi

if [ -f /etc/konahqss/ramnotify ]; then
  /etc/konahqss/setramnotify.sh $libs
fi

if [ -f /etc/konahqss/baseboost ]; then
  lib="$(ls -l $libs/libupower-glib.so.3|awk '{print $11}')"
  if [ -f $libs/$lib ]; then
    libsetoram $libs/$lib $lib
  else
    lib="$(ls -l $libs/libavahi-core.so.7|awk '{print $11}')"
    if [ -f $libs/$lib ]; then
      libsetoram $libs/$lib $lib
    fi
  fi
fi

# set to ram for sound server
if [ -x /usr/bin/pipewire ] && [ ! -f /etc/konahqss/ramserver ]; then
  lib="libpipewire-0.3.so.0"
  libs=$(getlibs $lib)
  if [ ! -z "$libs" ] && [ -f $libs/$lib ]; then
    lib=$(ls -l $libs/$lib|awk '{print $11}')
    libsetoram $libs/$lib $lib
  fi
fi
if [ -x /usr/bin/jackd ]; then
  jacklib="libjack.so.0"
  libs=$(getlibs $lib)
  if [ ! -z "$libs" ] && [ -f $libs/$lib ]; then
    lib=$(ls -l $libs/$lib|awk '{print $11}')
    libsetoram $libs/$lib $lib
  fi
fi

rm -f /etc/ld.so.cache
ldconfig

/etc/konahqss/refreshpm.sh $libs

# set TCP read buffer size
if [ -f /etc/konahqss/rmem ]; then
  minsz=$(cat /proc/sys/net/ipv4/tcp_rmem | awk '{print $1}')
  maxsz=$(cat /proc/sys/net/ipv4/tcp_rmem | awk '{print $3}')
  rmem="$(cat /etc/konahqss/rmem)"
  echo $minsz $rmem $maxsz > /proc/sys/net/ipv4/tcp_rmem
fi

# set server to ram
/etc/konahqss/setramserver.sh

# set player to ram
/etc/konahqss/setplayertoram.sh

# set mtu
if [ -f /etc/konahqss/mtu ]; then
  [ -z "$(ifconfig | grep mtu|grep -v ^lo|cut -d':' -f1)" ] && sleep 10
  ifconfig | grep mtu|grep -v ^lo|cut -d':' -f1 | while read line; do
    ifconfig $line mtu $(cat /etc/konahqss/mtu)
  done
fi

# initilize register & memories
/etc/konahqss/initmem.sh
#crontab /etc/konahqss/initmem.conf

